==> confluence-flyingpdf-plugin-6.3.8-sources.jar: com/atlassian/confluence/extra/flyingpdf/impl/PdfExportLongRunningTaskFactory.java <==
package com.atlassian.confluence.extra.flyingpdf.impl;

import com.atlassian.confluence.extra.flyingpdf.html.DecorationPolicy;
import com.atlassian.confluence.importexport.ImportExportManager;
import com.atlassian.confluence.importexport.impl.ExportFileNameGenerator;
import com.atlassian.confluence.security.GateKeeper;
import com.atlassian.confluence.spaces.Space;
import com.atlassian.confluence.spaces.SpaceManager;
import com.atlassian.confluence.util.i18n.I18NBean;
import com.atlassian.plugin.spring.scanner.annotation.imports.ComponentImport;
import com.atlassian.sal.api.transaction.TransactionTemplate;
import com.atlassian.user.User;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * Factory class for constructing suitably wired PdfExportLongRunningTasks.
 */
@Component
public class PdfExportLongRunningTaskFactory {
    private final GateKeeper gateKeeper;
    private final SpaceManager spaceManager;
    private final PdfExportSemaphore pdfExportSemaphore;
    private final ImportExportManager importExportManager;
    private final TransactionTemplate transactionTemplate;
    private final ExportFileNameGenerator pdfExportFileNameGenerator;
    private final DiagnosticPdfExporterService flyingPdfExporterService;

    public PdfExportLongRunningTaskFactory(
            @ComponentImport GateKeeper gateKeeper,
            @ComponentImport SpaceManager spaceManager,
            @ComponentImport ImportExportManager importExportManager,
            @ComponentImport TransactionTemplate transactionTemplate,
            PdfExportSemaphore pdfExportSemaphore,
            ExportFileNameGenerator pdfExportFileNameGenerator,
            DiagnosticPdfExporterService flyingPdfExporterService) {
        this.gateKeeper = gateKeeper;
        this.spaceManager = spaceManager;
        this.pdfExportSemaphore = pdfExportSemaphore;
        this.importExportManager = importExportManager;
        this.transactionTemplate = transactionTemplate;
        this.pdfExportFileNameGenerator = pdfExportFileNameGenerator;
        this.flyingPdfExporterService = flyingPdfExporterService;
    }

    public PdfExportLongRunningTask createNewLongRunningTask(List<String> contentToBeExported, Space space,
                                                             User remoteUser, String contextPath, DecorationPolicy decorations) {
        PdfExportLongRunningTask task = new PdfExportLongRunningTask(contentToBeExported, space, remoteUser,
                contextPath, pdfExportSemaphore, decorations);
        task.setImportExportManager(importExportManager);
        task.setSpaceManager(spaceManager);
        task.setFlyingPdfExporterService(flyingPdfExporterService);
        task.setTransactionTemplate(transactionTemplate);
        task.setGateKeeper(gateKeeper);
        return task;
    }

    public ContentTreeLongRunningTask createNewContentTreeLongRunningTask(I18NBean i18NBean, Space space,
                                                                          User remoteUser, String contextPath) {
        return new ContentTreeLongRunningTask(importExportManager, transactionTemplate, i18NBean, space, remoteUser,
                gateKeeper, contextPath, pdfExportFileNameGenerator, pdfExportSemaphore);
    }

}

==> confluence-flyingpdf-plugin-8.0.0-sources.jar: com/atlassian/confluence/extra/flyingpdf/impl/PdfExportLongRunningTaskFactory.java <==
package com.atlassian.confluence.extra.flyingpdf.impl;

import com.atlassian.confluence.extra.flyingpdf.html.DecorationPolicy;
import com.atlassian.confluence.importexport.ImportExportManager;
import com.atlassian.confluence.importexport.impl.ExportFileNameGenerator;
import com.atlassian.confluence.security.GateKeeper;
import com.atlassian.confluence.spaces.Space;
import com.atlassian.confluence.spaces.SpaceManager;
import com.atlassian.confluence.util.i18n.I18NBean;
import com.atlassian.plugin.spring.scanner.annotation.imports.ComponentImport;
import com.atlassian.sal.api.transaction.TransactionTemplate;
import com.atlassian.user.User;
import org.springframework.stereotype.Component;

import java.util.List;

/**
 * Factory class for constructing suitably wired PdfExportLongRunningTasks.
 */
@Component
public class PdfExportLongRunningTaskFactory {
    private final GateKeeper gateKeeper;
    private final SpaceManager spaceManager;
    private final PdfExportSemaphore pdfExportSemaphore;
    private final ImportExportManager importExportManager;
    private final TransactionTemplate transactionTemplate;
    private final ExportFileNameGenerator pdfExportFileNameGenerator;
    private final BigBrotherPdfExporterService pdfExporterService;

    public PdfExportLongRunningTaskFactory(
            @ComponentImport GateKeeper gateKeeper,
            @ComponentImport SpaceManager spaceManager,
            @ComponentImport ImportExportManager importExportManager,
            @ComponentImport TransactionTemplate transactionTemplate,
            PdfExportSemaphore pdfExportSemaphore,
            ExportFileNameGenerator pdfExportFileNameGenerator,
            BigBrotherPdfExporterService pdfExporterService) {
        this.gateKeeper = gateKeeper;
        this.spaceManager = spaceManager;
        this.pdfExportSemaphore = pdfExportSemaphore;
        this.importExportManager = importExportManager;
        this.transactionTemplate = transactionTemplate;
        this.pdfExportFileNameGenerator = pdfExportFileNameGenerator;
        this.pdfExporterService = pdfExporterService;
    }

    public PdfExportLongRunningTask createNewLongRunningTask(List<String> contentToBeExported, Space space,
                                                             User remoteUser, String contextPath, DecorationPolicy decorations) {
        PdfExportLongRunningTask task = new PdfExportLongRunningTask(contentToBeExported, space, remoteUser,
                contextPath, pdfExportSemaphore, decorations);
        task.setImportExportManager(importExportManager);
        task.setSpaceManager(spaceManager);
        task.setFlyingPdfExporterService(pdfExporterService);
        task.setTransactionTemplate(transactionTemplate);
        task.setGateKeeper(gateKeeper);
        return task;
    }

    public ContentTreeLongRunningTask createNewContentTreeLongRunningTask(I18NBean i18NBean, Space space,
                                                                          User remoteUser, String contextPath) {
        return new ContentTreeLongRunningTask(importExportManager, transactionTemplate, i18NBean, space, remoteUser,
                gateKeeper, contextPath, pdfExportFileNameGenerator, pdfExportSemaphore);
    }

}
